==> flutter_hesabe_payment-2.0.1.tar.gz: ios/Classes/SwiftFlutterHesabePlugin.swift <==
import Flutter
import UIKit


public class SwiftFlutterHesabePlugin: NSObject, FlutterPlugin, UINavigationControllerDelegate {

var results : FlutterResult!
var navigationController: UINavigationController?

override init(){
super.init()
}

public static func register(with registrar: FlutterPluginRegistrar) {
let channel = FlutterMethodChannel(name: "flutter_hesabe_payment", binaryMessenger: registrar.messenger())
let instance = SwiftFlutterHesabePlugin()
registrar.addMethodCallDelegate(instance, channel: channel)
}


public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
results = result

if(call.method.elementsEqual("payment"))
{

let arguments = call.arguments as! NSDictionary
// let arguments = call.arguments as! [String:Any]

var price : String!
if let amount = arguments["price"] as? Double{
price = String(amount)
}else{
price = "0.0"
}

let paymentRequest_ = PaymentRequest(amount: price)

let vc = HesabeGatewayVC()

vc.paymentRequest = paymentRequest_

vc.url = arguments["cred_url"] as? String ?? ""

vc.accessCode = arguments["access_code"] as? String ?? ""
vc.merchantCode = arguments["merchant_code"] as? String ?? ""
vc.merchantIV = arguments["iv_key"] as? String ?? ""
vc.merchantKey = arguments["secret_key"] as? String ?? ""

vc.modalPresentationStyle = .overFullScreen // to

let rootViewController = UIApplication.shared.keyWindow?.rootViewController
if (rootViewController is UINavigationController) {
(rootViewController as! UINavigationController).pushViewController(vc,animated:true)
} else {
let navigationController:UINavigationController! = UINavigationController(rootViewController:vc)
rootViewController!.present(navigationController, animated:true, completion:nil)
}

navigationController?.present(vc, animated: true, completion: nil)
}
}

}

==> flutter_hesabe_payment-2.0.2.tar.gz: ios/Classes/SwiftFlutterHesabePlugin.swift <==
import Flutter
import UIKit


public class SwiftFlutterHesabePlugin: NSObject, FlutterPlugin, UINavigationControllerDelegate {

var results : FlutterResult!
var navigationController: UINavigationController?

override init(){
super.init()
}

public static func register(with registrar: FlutterPluginRegistrar) {
let channel = FlutterMethodChannel(name: "flutter_hesabe_payment", binaryMessenger: registrar.messenger())
let instance = SwiftFlutterHesabePlugin()
registrar.addMethodCallDelegate(instance, channel: channel)
}


public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
results = result

if(call.method.elementsEqual("payment"))
{

let arguments = call.arguments as! NSDictionary
// let arguments = call.arguments as! [String:Any]

var price : String!
if let amount = arguments["price"] as? Double{
price = String(amount)
}else{
price = "0.0"
}


let paymentRequest_ = PaymentRequest(amount: price, merchantCode: arguments["merchant_code"] as? String ?? "", responseUrl: arguments["response_URL"] as? String ?? "", failureUrl: arguments["failure_URL"] as? String ?? "")

let vc = HesabeGatewayVC()

vc.paymentRequest = paymentRequest_

vc.url = arguments["cred_url"] as? String ?? ""

vc.accessCode = arguments["access_code"] as? String ?? ""
vc.merchantCode = arguments["merchant_code"] as? String ?? ""
vc.merchantIV = arguments["iv_key"] as? String ?? ""
vc.merchantKey = arguments["secret_key"] as? String ?? ""

vc.responseURL = arguments["response_URL"] as? String ?? ""
vc.failureURL = arguments["failure_URL"] as? String ?? ""

vc.modalPresentationStyle = .overFullScreen // to

let rootViewController = UIApplication.shared.keyWindow?.rootViewController
if (rootViewController is UINavigationController) {
(rootViewController as! UINavigationController).pushViewController(vc,animated:true)
} else {
let navigationController:UINavigationController! = UINavigationController(rootViewController:vc)
rootViewController!.present(navigationController, animated:true, completion:nil)
}

navigationController?.present(vc, animated: true, completion: nil)
}
}

}
